#
# Release Notes: https://github.com/chef/ohai/blob/master/CHANGELOG.md
#
# Conditional build:
%bcond_with	tests		# build without tests

%define pkgname ohai
Summary:	Profiles your system and emits JSON
Name:		ruby-%{pkgname}
Version:	14.2.4
Release:	3
License:	Apache v2.0
Group:		Development/Languages
Source0:	https://github.com/opscode/ohai/archive/v%{version}/%{pkgname}-%{version}.tar.gz
# Source0-md5:	09fe81cb0b178bad4ad9898c6cc72c57
Patch1:		platform-pld.patch
URL:		https://docs.getchef.com/ohai.html
BuildRequires:	rpm-rubyprov
BuildRequires:	rpmbuild(macros) >= 1.665
BuildRequires:	ruby-rake
BuildRequires:	sed >= 4.0
%if %{with tests}
BuildRequires:	ruby-ffi >= 1.9
BuildRequires:	ruby-ffi-yajl >= 1.1
BuildRequires:	ruby-ipaddress
BuildRequires:	ruby-mixlib-config
BuildRequires:	ruby-mixlib-log
BuildRequires:	ruby-mixlib-shellout >= 1.2
BuildRequires:	ruby-rspec
BuildRequires:	ruby-systemu >= 2.6.4
%endif
Requires:	iproute2
Requires:	lsb-release
Requires:	mount
Requires:	ruby(abi) >= 2.0
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Ohai detects data about your operating system and prints out a JSON
data blob. It can be used standalone, but it's primary purpose is to
provide node data to Chef.

%package doc
Summary:	Documentation for %{name}
Group:		Documentation
Requires:	%{name} = %{version}-%{release}

%description doc
This package contains documentation for %{name}.

%prep
%setup -q -n ohai-%{version}
%patch1 -p1
%{__sed} -i -e '1 s,#!.*ruby,#!%{__ruby},' bin/*

# don't need shellout 2.0 yet, but 2.0 is ok
%{__sed} -i -e '/mixlib-shellout/ s/">= 2.0.0.rc.0", "< 3.0"/">= 1.2", "< 3.0"/' %{pkgname}.gemspec
# optional
%{__sed} -i -e '/net-dhcp/d' %{pkgname}.gemspec
# platform specific and optional
%{__sed} -i -e '/wmi-lite/d' %{pkgname}.gemspec
%{__sed} -i -e '/plist/d' %{pkgname}.gemspec
# dev dep
%{__sed} -i -e '/rake/d' %{pkgname}.gemspec

# no plist and not darwin so don't care
rm spec/unit/plugins/darwin/system_profiler_spec.rb

# can't figure how to fix -r rubygems does not help
# ohai-6.16.0/spec/unit/plugins/ruby_spec.rb:52:in `block in <top (required)>': uninitialized constant Gem (NameError)
rm spec/unit/plugins/ruby_spec.rb

%build
# make gemspec self-contained
ruby -r rubygems -e 'spec = eval(File.read("%{pkgname}.gemspec"))
	File.open("%{pkgname}-%{version}.gemspec", "w") do |file|
	file.puts spec.to_ruby_for_cache
end'

%if %{with tests}
# Occasionally fails with "undefined method `rfc2822' for nil:NilClass" during
# mock. Unsure why - disable for now.
#sed -i 's^Time.should_receive(:now)^^' spec/ohai/plugins/ohai_time_spec.rb
LC_ALL=en_US.utf8 \
rake -r rubygems spec
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{ruby_vendorlibdir},%{ruby_specdir},%{_bindir},%{_mandir}/man1}
cp -a bin/* $RPM_BUILD_ROOT%{_bindir}
cp -a lib/* $RPM_BUILD_ROOT%{ruby_vendorlibdir}
cp -p %{pkgname}-%{version}*.gemspec $RPM_BUILD_ROOT%{ruby_specdir}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.md CHANGELOG.md RELEASE_NOTES.md OHAI_MVPS.md NOTICE
%attr(755,root,root) %{_bindir}/ohai
%{ruby_vendorlibdir}/%{pkgname}.rb
%{ruby_vendorlibdir}/%{pkgname}
%{ruby_specdir}/%{pkgname}-%{version}*.gemspec
%changelog
* Sat May 16 2020 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/ruby-ohai.git;a=log;h=master

* Sat May 16 2020 Jan Rękorajski <baggins@pld-linux.org> ae471ff
- release 3 (by relup.sh)

* Wed May 06 2020 Elan Ruusamäe <glen@pld-linux.org> b4c761a
- Release 2, rebuild with Ruby 2.6

* Tue Sep 18 2018 Elan Ruusamäe <glen@pld-linux.org> 85ad1ec
- up to 14.2.4

* Tue Sep 18 2018 Elan Ruusamäe <glen@pld-linux.org> 2c54e26
- Merge branch 'chef-14'

* Tue Sep 18 2018 Elan Ruusamäe <glen@pld-linux.org> 9993561
- up to 14.2.0

* Tue Sep 18 2018 Elan Ruusamäe <glen@pld-linux.org> 373c014
- update release notes url

* Mon Jul 16 2018 Jan Rękorajski <baggins@pld-linux.org> 686e2c7
- up to 14.2.0

* Mon Jul 16 2018 Elan Ruusamäe <glen@pld-linux.org> b5b87a6
- up  to 14.1.7

* Sun Nov 12 2017 Jan Rękorajski <baggins@pld-linux.org> a8716c5
- release 5 (by relup.sh)

* Thu Oct 26 2017 Jan Rękorajski <baggins@pld-linux.org> 4b93aa8
- release 4 (by relup.sh)

* Wed Oct 25 2017 Jan Rękorajski <baggins@pld-linux.org> a3971d3
- rebuild with ruby 2.3
- release 3 (by relup.sh)

* Thu Jun 02 2016 Elan Ruusamäe <glen@delfi.ee> 0b39822
- no longer using rake to build package

* Wed Jun 01 2016 Elan Ruusamäe <glen@delfi.ee> 68ecfc8
- drop obsolete manpage

* Wed Jun 01 2016 Elan Ruusamäe <glen@delfi.ee> bde0a3a
- drop mime-types dep

* Wed Jun 01 2016 Elan Ruusamäe <glen@delfi.ee> 5985c42
- remove deps autogenerated from rubygems

* Wed Jun 01 2016 Elan Ruusamäe <glen@delfi.ee> 80c726d
- net/dhcp no longer required in ohai code

* Wed Jun 01 2016 Elan Ruusamäe <glen@delfi.ee> 8444e82
- requires ruby 2.0 according to .gemspec

* Wed Jun 01 2016 Elan Ruusamäe <glen@delfi.ee> e5bdf1c
- skip plist dep

* Wed Jun 01 2016 Elan Ruusamäe <glen@delfi.ee> 2b26b7f
- different way of writing .gemspec

* Wed Jun 01 2016 Elan Ruusamäe <glen@delfi.ee> 5218c8b
- update source to 8.16.0

